
#ifndef TEXTEMOTICONSWIDGETS_EXPORT_H
#define TEXTEMOTICONSWIDGETS_EXPORT_H

#ifdef TEXTEMOTICONSWIDGETS_STATIC_DEFINE
#  define TEXTEMOTICONSWIDGETS_EXPORT
#  define TEXTEMOTICONSWIDGETS_NO_EXPORT
#else
#  ifndef TEXTEMOTICONSWIDGETS_EXPORT
#    ifdef KF6TextEmoticonsWidgets_EXPORTS
        /* We are building this library */
#      define TEXTEMOTICONSWIDGETS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTEMOTICONSWIDGETS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTEMOTICONSWIDGETS_NO_EXPORT
#    define TEXTEMOTICONSWIDGETS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTEMOTICONSWIDGETS_DEPRECATED
#  define TEXTEMOTICONSWIDGETS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTEMOTICONSWIDGETS_DEPRECATED_EXPORT
#  define TEXTEMOTICONSWIDGETS_DEPRECATED_EXPORT TEXTEMOTICONSWIDGETS_EXPORT TEXTEMOTICONSWIDGETS_DEPRECATED
#endif

#ifndef TEXTEMOTICONSWIDGETS_DEPRECATED_NO_EXPORT
#  define TEXTEMOTICONSWIDGETS_DEPRECATED_NO_EXPORT TEXTEMOTICONSWIDGETS_NO_EXPORT TEXTEMOTICONSWIDGETS_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTEMOTICONSWIDGETS_NO_DEPRECATED
#    define TEXTEMOTICONSWIDGETS_NO_DEPRECATED
#  endif
#endif

#endif /* TEXTEMOTICONSWIDGETS_EXPORT_H */
