
#ifndef TEXTEDITTEXTTOSPEECH_EXPORT_H
#define TEXTEDITTEXTTOSPEECH_EXPORT_H

#ifdef TEXTEDITTEXTTOSPEECH_STATIC_DEFINE
#  define TEXTEDITTEXTTOSPEECH_EXPORT
#  define TEXTEDITTEXTTOSPEECH_NO_EXPORT
#else
#  ifndef TEXTEDITTEXTTOSPEECH_EXPORT
#    ifdef KF6TextEditTextToSpeech_EXPORTS
        /* We are building this library */
#      define TEXTEDITTEXTTOSPEECH_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTEDITTEXTTOSPEECH_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTEDITTEXTTOSPEECH_NO_EXPORT
#    define TEXTEDITTEXTTOSPEECH_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTEDITTEXTTOSPEECH_DEPRECATED
#  define TEXTEDITTEXTTOSPEECH_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTEDITTEXTTOSPEECH_DEPRECATED_EXPORT
#  define TEXTEDITTEXTTOSPEECH_DEPRECATED_EXPORT TEXTEDITTEXTTOSPEECH_EXPORT TEXTEDITTEXTTOSPEECH_DEPRECATED
#endif

#ifndef TEXTEDITTEXTTOSPEECH_DEPRECATED_NO_EXPORT
#  define TEXTEDITTEXTTOSPEECH_DEPRECATED_NO_EXPORT TEXTEDITTEXTTOSPEECH_NO_EXPORT TEXTEDITTEXTTOSPEECH_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTEDITTEXTTOSPEECH_NO_DEPRECATED
#    define TEXTEDITTEXTTOSPEECH_NO_DEPRECATED
#  endif
#endif

#endif /* TEXTEDITTEXTTOSPEECH_EXPORT_H */
