
#ifndef TEXTEMOTICONSCORE_EXPORT_H
#define TEXTEMOTICONSCORE_EXPORT_H

#ifdef TEXTEMOTICONSCORE_STATIC_DEFINE
#  define TEXTEMOTICONSCORE_EXPORT
#  define TEXTEMOTICONSCORE_NO_EXPORT
#else
#  ifndef TEXTEMOTICONSCORE_EXPORT
#    ifdef KF6TextEmoticonsCore_EXPORTS
        /* We are building this library */
#      define TEXTEMOTICONSCORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTEMOTICONSCORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTEMOTICONSCORE_NO_EXPORT
#    define TEXTEMOTICONSCORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTEMOTICONSCORE_DEPRECATED
#  define TEXTEMOTICONSCORE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTEMOTICONSCORE_DEPRECATED_EXPORT
#  define TEXTEMOTICONSCORE_DEPRECATED_EXPORT TEXTEMOTICONSCORE_EXPORT TEXTEMOTICONSCORE_DEPRECATED
#endif

#ifndef TEXTEMOTICONSCORE_DEPRECATED_NO_EXPORT
#  define TEXTEMOTICONSCORE_DEPRECATED_NO_EXPORT TEXTEMOTICONSCORE_NO_EXPORT TEXTEMOTICONSCORE_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTEMOTICONSCORE_NO_DEPRECATED
#    define TEXTEMOTICONSCORE_NO_DEPRECATED
#  endif
#endif

#endif /* TEXTEMOTICONSCORE_EXPORT_H */
