
#ifndef TEXTAUTOCORRECTIONCORE_EXPORT_H
#define TEXTAUTOCORRECTIONCORE_EXPORT_H

#ifdef TEXTAUTOCORRECTIONCORE_STATIC_DEFINE
#  define TEXTAUTOCORRECTIONCORE_EXPORT
#  define TEXTAUTOCORRECTIONCORE_NO_EXPORT
#else
#  ifndef TEXTAUTOCORRECTIONCORE_EXPORT
#    ifdef KF6TextAutoCorrectionCore_EXPORTS
        /* We are building this library */
#      define TEXTAUTOCORRECTIONCORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTAUTOCORRECTIONCORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTAUTOCORRECTIONCORE_NO_EXPORT
#    define TEXTAUTOCORRECTIONCORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTAUTOCORRECTIONCORE_DEPRECATED
#  define TEXTAUTOCORRECTIONCORE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTAUTOCORRECTIONCORE_DEPRECATED_EXPORT
#  define TEXTAUTOCORRECTIONCORE_DEPRECATED_EXPORT TEXTAUTOCORRECTIONCORE_EXPORT TEXTAUTOCORRECTIONCORE_DEPRECATED
#endif

#ifndef TEXTAUTOCORRECTIONCORE_DEPRECATED_NO_EXPORT
#  define TEXTAUTOCORRECTIONCORE_DEPRECATED_NO_EXPORT TEXTAUTOCORRECTIONCORE_NO_EXPORT TEXTAUTOCORRECTIONCORE_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTAUTOCORRECTIONCORE_NO_DEPRECATED
#    define TEXTAUTOCORRECTIONCORE_NO_DEPRECATED
#  endif
#endif

#endif /* TEXTAUTOCORRECTIONCORE_EXPORT_H */
