// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef TEXTGRAMMARCHECK_VERSION_H
#define TEXTGRAMMARCHECK_VERSION_H

#define TEXTGRAMMARCHECK_VERSION_STRING "2.0.1"
#define TEXTGRAMMARCHECK_VERSION_MAJOR 2
#define TEXTGRAMMARCHECK_VERSION_MINOR 0
#define TEXTGRAMMARCHECK_VERSION_PATCH 1
#define TEXTGRAMMARCHECK_VERSION ((2<<16)|(0<<8)|(1))

#endif
