
#ifndef TEXTCUSTOMEDITOR_EXPORT_H
#define TEXTCUSTOMEDITOR_EXPORT_H

#ifdef TEXTCUSTOMEDITOR_STATIC_DEFINE
#  define TEXTCUSTOMEDITOR_EXPORT
#  define TEXTCUSTOMEDITOR_NO_EXPORT
#else
#  ifndef TEXTCUSTOMEDITOR_EXPORT
#    ifdef KF6TextCustomEditor_EXPORTS
        /* We are building this library */
#      define TEXTCUSTOMEDITOR_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTCUSTOMEDITOR_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTCUSTOMEDITOR_NO_EXPORT
#    define TEXTCUSTOMEDITOR_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTCUSTOMEDITOR_DEPRECATED
#  define TEXTCUSTOMEDITOR_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTCUSTOMEDITOR_DEPRECATED_EXPORT
#  define TEXTCUSTOMEDITOR_DEPRECATED_EXPORT TEXTCUSTOMEDITOR_EXPORT TEXTCUSTOMEDITOR_DEPRECATED
#endif

#ifndef TEXTCUSTOMEDITOR_DEPRECATED_NO_EXPORT
#  define TEXTCUSTOMEDITOR_DEPRECATED_NO_EXPORT TEXTCUSTOMEDITOR_NO_EXPORT TEXTCUSTOMEDITOR_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTCUSTOMEDITOR_NO_DEPRECATED
#    define TEXTCUSTOMEDITOR_NO_DEPRECATED
#  endif
#endif

#endif /* TEXTCUSTOMEDITOR_EXPORT_H */
