
#ifndef TEXTAUTOCORRECTIONWIDGETS_EXPORT_H
#define TEXTAUTOCORRECTIONWIDGETS_EXPORT_H

#ifdef TEXTAUTOCORRECTIONWIDGETS_STATIC_DEFINE
#  define TEXTAUTOCORRECTIONWIDGETS_EXPORT
#  define TEXTAUTOCORRECTIONWIDGETS_NO_EXPORT
#else
#  ifndef TEXTAUTOCORRECTIONWIDGETS_EXPORT
#    ifdef KF6TextAutoCorrectionWidgets_EXPORTS
        /* We are building this library */
#      define TEXTAUTOCORRECTIONWIDGETS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTAUTOCORRECTIONWIDGETS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTAUTOCORRECTIONWIDGETS_NO_EXPORT
#    define TEXTAUTOCORRECTIONWIDGETS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTAUTOCORRECTIONWIDGETS_DEPRECATED
#  define TEXTAUTOCORRECTIONWIDGETS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTAUTOCORRECTIONWIDGETS_DEPRECATED_EXPORT
#  define TEXTAUTOCORRECTIONWIDGETS_DEPRECATED_EXPORT TEXTAUTOCORRECTIONWIDGETS_EXPORT TEXTAUTOCORRECTIONWIDGETS_DEPRECATED
#endif

#ifndef TEXTAUTOCORRECTIONWIDGETS_DEPRECATED_NO_EXPORT
#  define TEXTAUTOCORRECTIONWIDGETS_DEPRECATED_NO_EXPORT TEXTAUTOCORRECTIONWIDGETS_NO_EXPORT TEXTAUTOCORRECTIONWIDGETS_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTAUTOCORRECTIONWIDGETS_NO_DEPRECATED
#    define TEXTAUTOCORRECTIONWIDGETS_NO_DEPRECATED
#  endif
#endif

#endif /* TEXTAUTOCORRECTIONWIDGETS_EXPORT_H */
